# Architecture

This repo is set up to be a monorepo to help manage different projects under the `mackenzii` umbrella. The repo is divided into the following:
- libs: libraries which are package-like and meant to be consumed in a project
  - types: shared types between the remaining libs/projects
- projects: end-products which are app-like meant to be built and deployed
  - frontend: the actual static website generator
  - manager: a placeholder for testing and/or managing multiple websites with the same static website generator
  - cms: a Strapi instance to manage larger sites

## /projects/frontend

The frontend is the main project which builds your website from your content config. The frontend is designed to work with dynamic content, i.e. it will not bake your content directly into the resulting HTML so that you can manage content separately. The types of pages that are generated are defined by page templates and are implemented by views (`/projects/frontend/src/views`).

## /projects/manager

This package helps manage multiple websites in one place. The `./sites` folder is hidden by default for the sake of the main `mackenzii` repo and is meant for maintaining dynamic content outside of source control. If you wish to have some sort of cloud sync or version control in your own setup, there are a few recommended options:
- (recommended option) fork `mackenzii` and use symbolic links in the `./sites` directory and include those sites in your cloud sync separate from `mackenzii`
- fork `mackenzii` and remove the gitignore for this directory to include your sites with your git host of choice (i.e. GitHub, GitLab, etc.)
- include `mackenzii` in some sort of cloud drive sync and make sure you set your sync client to ignore `node_modules`, `dist`, and other cache/build directories found in the gitignore

Note that some hosts, such as [surge.sh](https://surge.sh), do not allow for management of individual files and instead require that all files be pushed in one go. In that case, make sure the `/content` folder is present when the `/projects/frontend` project is built before syncing the entirety of `dist`.

## /projects/cms

In order to manage larger galleries, Mackenzii has a pre-configured [Strapi](https://docs.strapi.io/) package that can be used locally in combination with the scripts under the `sites` project which will pull data from Strapi into a format usable by Mackenzii. Note that this configured Strapi is _not_ meant to be hosted on a production server. If you do, make sure you do not commit any environment secrets to git (they should be gitignored) and read the docs on how to host Strapi. You will also want to point the bridge scripts to the hosted version instead of local, or consider repurposing them into a middleware server and have your Mackenzii point to the appropriate URLs instead of `/content/**`.
